import React from "react";

// Bootstrap Components
import { Container, Row, Col } from "react-bootstrap";

// Layout
import Schema from "../../../../Client/Schema";
import Layout from "../../../../Client/Layout";

// Server Side Data
import { getServerData } from "@/utils/http/getServerData";

import styles from "./page.module.css";

// All MetaData
export async function generateMetadata({ params, searchParams }, parent) {
  return {
    title: "EaseToLearn : Online Exam Preparation Site | Mock Test",
  };
}

export default async function page({ params, searchParams }) {
  const route =
    params?.route?.length > 1 ? params?.route?.join("/") : params?.route[0];
  const { data } = await getServerData({ slug: route }, true);

  // Schema Obj
  const schema = {
    faq: true,
    website: true,
    review: true,
    video: {
      name: "How does EaseToLearn Work?",
      url: "https://www.youtube.com/watch?v=3lhkCUPAFOY&t=8s",
      datePublished: "2023-05-04",
      uploadDate: "2023-05-04",
      thumbnailUrl: "https://media.easetolearn.com/CompanyLogo.png",
      description: "Fastest method of learning for exams",
    },
  };

  // Add Table code for responsiveness
  const addTableStart = (story) => {
    let addedTableStart = story.replace(
      /<table .*">/,
      '<div class="table_responsive"><table>'
    );
    let addedTableEnd = addedTableStart.replace("</table>", "</table></div>");
    return addedTableEnd;
  };

  return (
    <>
      <Schema schema={schema} />
      <Layout>
        <Container>
          <Row>
            <Col lg={9}>
              <h1 className={styles.wb_heading}>
                {data?.content?.topics?.contentName}
              </h1>

              {data?.content?.topics?.description ? (
                <div
                  dangerouslySetInnerHTML={{
                    __html: addTableStart(data?.content?.topics?.description),
                  }}
                />
              ) : (
                <></>
              )}
              <iframe className={styles?.video_embed} src={data?.content?.topics?.contentUrl} width={`100%`} height={600} />
            </Col>
            <Col lg={3}></Col>
          </Row>
        </Container>
      </Layout>
    </>
  );
}
