import axios from "axios";
import { routes } from "@/utils/http/Routes";

const convertArrayToObject = (array) => {
  const initialValue = {};
  return array.reduce((obj, item) => {
    return {
      ...obj,
      ...item,
    };
  }, initialValue);
};

const api = axios.create({
  baseURL: process.env.NEXT_PUBLIC_API_URL,
  headers: {
    "Content-Type": "application/json",
  },
});

// All Server Side Api Calls
export async function getServerData(params = {}, getContent = false) {
  let response;
  try {
    response = await axios.post(
      process.env.NEXT_PUBLIC_AUTH_URL,
      {
        username: "etl",
        password: "password",
      }
    );
  } catch (error) {
    console.log(error);
  }
  const token = response?.data?.data?.access_token;
  api.interceptors.request.use(async (config) => {
    config.headers["Authorization"] = `Bearer ${token}`;
    return config;
  });
  const getInfo = async (url, key, param = {}) => {
    const info = await api.get(url, { params: param });
    return { [`${key}`]: info?.data?.data };
  };
  let serverPromises = [];
  if(getContent) {
    serverPromises = [
      await getInfo(routes?.GET_CONTENT_NOW, "content", params),
    ];
  } else {
    serverPromises = [
      await getInfo(routes?.GET_TOPIC, "topic", params),
      await getInfo(routes?.GET_CONTENT, "content", params),
      await getInfo(routes?.GET_SUBTOPIC, "subtopic", params),
    ];
  }
  const getAll = await Promise.all(
    serverPromises
  );
  const data = convertArrayToObject(getAll);
  return {
    data,
  };
}
